import React from 'react';
import { Thumbnails } from './thumbnails';
import Style from './style';
import { ThemeType } from '../../constants';
export interface AccordionProps {
    /** Sets the border-radius of Accordion.Container, AccordionBox, and TitleWrapper */
    borderRadius?: keyof ThemeType['BORDER_RADIUS'];
    /** node(s) that will render only when expanded */
    children: React.ReactNode;
    /** when true, the accordion will be greyed out and the onClick prop will be disabled */
    disabled?: boolean;
    /** determine if the accordion is collapsed (false) or expanded (true) */
    isOpen: boolean;
    /** when true, border lines between accordions and title/children nodes will disappear */
    noBorder?: boolean;
    /** invoked when title node is clicked */
    onClick: (event: React.MouseEvent<HTMLDivElement, MouseEvent> | React.KeyboardEvent) => void;
    /** when true, the arrow is aligned flush with the right side of the component */
    rightAlignArrow?: boolean;
    /** node that will render whether collapsed or expanded */
    title: React.ReactNode;
}
interface Accordion extends React.FC<AccordionProps> {
    Container: typeof Style.Container;
    Content: typeof Style.Content;
    Thumbnails: typeof Thumbnails;
    Truncate: typeof Style.Truncate;
}
/**
 * A list of items that allows each item's content to be expanded and collapsed by clicking its title bar.
 *
 * The accordion component expands to reveal hidden information. They should be used when you need to fit a large amount of content but don't want to visually overwhelm the user.
 */
export declare const Accordion: Accordion;
export {};
//# sourceMappingURL=index.d.ts.map