import _extends from '@babel/runtime/helpers/extends';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import 'react';
import PropTypes from 'prop-types';
import { useTheme, jsx } from '@emotion/react';
import Loader from '../../shared-components/loader/index.js';
import ButtonContainer from '../../shared-components/container/index.js';
import withDeprecationWarning from '../../../../utils/withDeprecationWarning/index.js';
import { isLoadingPropFunction, deprecatedProperties } from '../../deprecatedPropsHandler.js';
import '../../../../constants/breakpoints/index.js';
import '../../../../constants/grid/index.js';
import '../../../../constants/mediaQueries/index.js';
import '../../../../constants/colors/primary.js';
import '../../../../constants/boxShadows/primary.js';
import '../../../../constants/colors/secondary.js';
import '../../../../constants/boxShadows/secondary.js';
import { COLORS_PROP_TYPES } from '../../../../constants/themes/types.js';
import { isDefined } from '../../../../utils/isDefined/index.js';
import { ButtonBase, ButtonContents, ButtonText } from '../../style.js';

var _excluded = ["buttonColor", "buttonType", "children", "disabled", "icon", "isFullWidth", "isLoading", "loading", "onClick", "textColor"];

var Button = _ref => {
  var {
    buttonColor,
    buttonType = 'primary',
    children,
    disabled = false,
    icon = null,
    isFullWidth = false,
    isLoading = false,
    loading = undefined,
    onClick,
    textColor
  } = _ref,
      rest = _objectWithoutProperties(_ref, _excluded);

  var theme = useTheme();
  var buttonColorWithTheme = buttonColor !== null && buttonColor !== void 0 ? buttonColor : theme.COLORS.primary;
  var loadingVal = loading === undefined ? isLoading : loading;
  var hasIcon = isDefined(icon) && icon !== false;
  return jsx(ButtonBase, _extends({
    buttonColor: buttonColorWithTheme,
    buttonType: buttonType,
    disabled: disabled,
    isFullWidth: isFullWidth,
    isLoading: loadingVal,
    onClick: !disabled && !loadingVal ? onClick : event => {
      event.preventDefault();
    },
    textColor: textColor,
    type: "button" // eslint-disable-next-line react/jsx-props-no-spreading

  }, rest), jsx(ButtonContents, {
    hasIcon: hasIcon,
    isFullWidth: isFullWidth,
    isLoading: loadingVal
  }, icon, jsx(ButtonText, {
    hasIcon: hasIcon,
    isLoading: loadingVal
  }, children)), jsx(Loader, {
    buttonColor: buttonColorWithTheme,
    buttonType: buttonType,
    disabled: disabled,
    isFullWidth: isFullWidth,
    isLoading: loadingVal,
    textColor: textColor
  }));
};

Button.Container = ButtonContainer;
Button.propTypes = {
  buttonColor: COLORS_PROP_TYPES,
  buttonType: PropTypes.oneOf(['primary', 'secondary', 'tertiary', 'quaternary']),
  children: PropTypes.node.isRequired,
  disabled: PropTypes.bool,
  icon: PropTypes.node,
  isFullWidth: PropTypes.bool,
  isLoading: PropTypes.bool,
  loading: isLoadingPropFunction,
  onClick: PropTypes.func,
  textColor: COLORS_PROP_TYPES
};
var ButtonComponent = withDeprecationWarning(Button, deprecatedProperties);

export { ButtonComponent as Button };
