import _extends from '@babel/runtime/helpers/extends';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import 'react';
import PropTypes from 'prop-types';
import { useTheme, jsx } from '@emotion/react';
import Loader from '../../shared-components/loader/index.js';
import Style from './style.js';
import withDeprecationWarning from '../../../../utils/withDeprecationWarning/index.js';
import { isLoadingPropFunction, deprecatedProperties } from '../../deprecatedPropsHandler.js';
import '../../../../constants/breakpoints/index.js';
import '../../../../constants/grid/index.js';
import '../../../../constants/mediaQueries/index.js';
import '../../../../constants/colors/primary.js';
import '../../../../constants/boxShadows/primary.js';
import '../../../../constants/colors/secondary.js';
import '../../../../constants/boxShadows/secondary.js';
import { COLORS_PROP_TYPES } from '../../../../constants/themes/types.js';
import { isDefined } from '../../../../utils/isDefined/index.js';

var _excluded = ["buttonColor", "buttonType", "children", "disabled", "icon", "isLoading", "loading", "onClick", "textColor"];
var RoundButton = _ref => {
  var {
    buttonColor,
    buttonType = 'primary',
    children,
    disabled = false,
    icon,
    isLoading = false,
    loading = undefined,
    onClick = () => undefined,
    textColor
  } = _ref,
      rest = _objectWithoutProperties(_ref, _excluded);

  var theme = useTheme();
  var buttonColorWithTheme = buttonColor !== null && buttonColor !== void 0 ? buttonColor : theme.COLORS.primary;
  var loadingVal = loading === undefined ? isLoading : loading;
  return jsx(Style.RoundButtonWrapper, null, jsx(Style.RoundButtonBase, _extends({
    onClick: !disabled && !isLoading ? onClick : () => false,
    disabled: disabled,
    buttonType: buttonType,
    buttonColor: buttonColorWithTheme,
    isLoading: loadingVal,
    type: "button",
    isFullWidth: false,
    textColor: textColor // eslint-disable-next-line react/jsx-props-no-spreading

  }, rest), icon, jsx(Loader, {
    buttonColor: buttonColorWithTheme,
    buttonType: buttonType,
    disabled: disabled,
    css: Style.roundButtonLoader(disabled, theme),
    isLoading: loadingVal,
    textColor: textColor
  })), isDefined(children) && jsx("p", {
    css: Style.roundButtonTextStyles(buttonColorWithTheme, theme, textColor)
  }, children));
};
RoundButton.Container = Style.RoundButtonContainer;
RoundButton.propTypes = {
  buttonColor: COLORS_PROP_TYPES,
  buttonType: PropTypes.oneOf(['primary', 'secondary', 'tertiary', 'quaternary', 'action']),
  children: PropTypes.node,
  disabled: PropTypes.bool,
  icon: PropTypes.node.isRequired,
  isLoading: PropTypes.bool,
  loading: isLoadingPropFunction,
  onClick: PropTypes.func,
  textColor: COLORS_PROP_TYPES
};
withDeprecationWarning(RoundButton, deprecatedProperties);

export { RoundButton };
