'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

require('react');
var PropTypes = require('prop-types');
var react = require('@emotion/react');
var style = require('./style.cjs');
var index = require('../../utils/isDefined/index.cjs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var PropTypes__default = /*#__PURE__*/_interopDefaultLegacy(PropTypes);

var getCalloutStyles = (theme, type) => {
  // Default values if no type provided
  var backgroundColor = theme.COLORS.infoLight;
  var textColor = theme.COLORS.primary;

  if (type === 'success') {
    backgroundColor = theme.COLORS.successLight;
    textColor = theme.COLORS.success;
  } else if (type === 'error') {
    backgroundColor = theme.COLORS.errorLight;
    textColor = theme.COLORS.error;
  }

  return {
    backgroundColor,
    textColor
  };
};
/**
 * Callouts should be used to provide valuable information or additional context on a page. One of the best examples of a callout is for product recommendations.
 *
 * `Callout` will cover the entirety of the container that holds it. You may optionally wrap it with `Callout.Container` which will set the `max-width` to `327px`.
 *
 * If you use a glyph as callout icon the recommended dimesions are 48x48 pixels (which is the default for Glyphs)
 */


var Callout = _ref => {
  var {
    children,
    icon,
    type
  } = _ref;
  var theme = react.useTheme();
  var {
    backgroundColor,
    textColor
  } = getCalloutStyles(theme, type);
  return react.jsx(style["default"].CalloutContainer, {
    backgroundColor: backgroundColor
  }, react.jsx(style["default"].Text, {
    textColor: textColor
  }, children), index.isDefined(icon) && icon !== false && react.jsx(style["default"].Icon, {
    iconColor: textColor
  }, icon));
};
Callout.Container = style["default"].ParentContainer;
Callout.propTypes = {
  children: PropTypes__default["default"].node.isRequired,
  icon: PropTypes__default["default"].node,
  type: PropTypes__default["default"].oneOf(['error', 'success'])
};

exports.Callout = Callout;
