'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('@babel/runtime/helpers/extends');
var _defineProperty = require('@babel/runtime/helpers/defineProperty');
var React = require('react');
var PropTypes = require('prop-types');
var Slider = require('react-slick');
var index = require('./arrow/index.cjs');
var style = require('./style.cjs');
var index$1 = require('../../utils/isDefined/index.cjs');
var react = require('@emotion/react');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _extends__default = /*#__PURE__*/_interopDefaultLegacy(_extends);
var _defineProperty__default = /*#__PURE__*/_interopDefaultLegacy(_defineProperty);
var PropTypes__default = /*#__PURE__*/_interopDefaultLegacy(PropTypes);
var Slider__default = /*#__PURE__*/_interopDefaultLegacy(Slider);

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty__default["default"](target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
var FIRST_INDEX = 0;
var BASE_SLIDER_CONFIG = {
  focusOnSelect: true,
  pauseOnHover: true,
  slidesToScroll: 1,
  variableWidth: true
}; // TODO-eslint: Reduce cognitive complexity of component

/* eslint-disable sonarjs/cognitive-complexity */

/**
 * Carousels should be used to provide valuable information or additional context on a page. One of the best examples of a Carousel is for product recommendations.
 *
 * The property `numCardsVisible` will define the width of the Carousel Container.
 *
 * An array of `Carousel.Card` must be used for the carousel content. It includes the base styles for the Card which may be extended as shown above.
 */

var Carousel = _ref => {
  var {
    autoplay = false,
    autoplaySpeed = 5000,
    bottomRightAlignedArrows = false,
    carouselType = 'primary',
    centerMode = true,
    children,
    hideArrows = false,
    hideDots = false,
    infinite = false,
    numCardsVisible
  } = _ref;

  var getLastIndex = () => {
    var numberSlides = children.length;
    return numberSlides - numCardsVisible;
  };

  var [currentIndex, setCurrentIndex] = React.useState(FIRST_INDEX);
  var [lastIndex, setLastIndex] = React.useState(getLastIndex);
  var hasUserInteractedRef = React.useRef(false);
  var timeoutIdRef = React.useRef(null);
  var slider = React.useRef(null);

  var shouldReplay = () => {
    var onLastCard = currentIndex === lastIndex;
    return autoplay && !infinite && onLastCard && !hasUserInteractedRef.current;
  };

  var replay = () => {
    timeoutIdRef.current = window.setTimeout(() => {
      if (slider.current) {
        slider.current.slickGoTo(FIRST_INDEX);
      }
    }, autoplaySpeed);
  };

  var updateLastIndex = () => {
    var updatedLastIndex = getLastIndex();

    if (lastIndex !== updatedLastIndex) {
      setLastIndex(updatedLastIndex);
    }

    if (slider.current && currentIndex > updatedLastIndex) {
      slider.current.slickGoTo(updatedLastIndex);
    }
  };

  React.useEffect(() => {
    if (shouldReplay()) {
      replay();
    }

    updateLastIndex();
  });

  var onCardChange = (_oldIndex, nextIndex) => {
    timeoutIdRef.current = null;
    setCurrentIndex(nextIndex);
  };

  var onUserInteraction = () => {
    if (index$1.isDefined(timeoutIdRef.current)) {
      clearTimeout(timeoutIdRef.current);
    }

    hasUserInteractedRef.current = true;

    if (slider.current) {
      slider.current.slickPause();
    }
  };

  var carouselSettings = _objectSpread(_objectSpread({}, BASE_SLIDER_CONFIG), {}, {
    arrows: !hideArrows,
    autoplay,
    autoplaySpeed,
    beforeChange: onCardChange,
    centerMode: numCardsVisible > 1 || infinite ? false : centerMode,
    dots: !hideDots && !bottomRightAlignedArrows,
    infinite,
    nextArrow: react.jsx(index["default"], {
      bottomRightAlignedArrows: bottomRightAlignedArrows,
      disabled: currentIndex === lastIndex && !infinite,
      next: true,
      onClick: onUserInteraction
    }),
    onSwipe: onUserInteraction,
    prevArrow: react.jsx(index["default"], {
      bottomRightAlignedArrows: bottomRightAlignedArrows,
      disabled: currentIndex === FIRST_INDEX && !infinite,
      onClick: onUserInteraction,
      prev: true
    }),
    slidesToShow: numCardsVisible
  });

  return react.jsx(style["default"].OuterContainer, {
    numCardsVisible: numCardsVisible
  }, react.jsx(style["default"].InnerContainer, {
    carouselType: carouselType,
    onClick: onUserInteraction
  }, react.jsx(Slider__default["default"], _extends__default["default"]({
    ref: slider
  }, carouselSettings), children)));
};
/* eslint-enable sonarjs/cognitive-complexity */

Carousel.Card = style["default"].Card;
Carousel.propTypes = {
  autoplay: PropTypes__default["default"].bool,
  autoplaySpeed: PropTypes__default["default"].number,
  bottomRightAlignedArrows: PropTypes__default["default"].bool,
  carouselType: PropTypes__default["default"].oneOf(['primary', 'secondary']),
  centerMode: PropTypes__default["default"].bool,
  children: PropTypes__default["default"].arrayOf(PropTypes__default["default"].node).isRequired,
  hideArrows: PropTypes__default["default"].bool,
  hideDots: PropTypes__default["default"].bool,
  infinite: PropTypes__default["default"].bool,
  numCardsVisible: PropTypes__default["default"].oneOf([1, 2, 3]).isRequired
};

exports.Carousel = Carousel;
