'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

require('react');
var PropTypes = require('prop-types');
var react = require('@emotion/react');
var style = require('./style.cjs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var PropTypes__default = /*#__PURE__*/_interopDefaultLegacy(PropTypes);

var getStyles = _ref => {
  var {
    isLowContrast,
    status,
    theme
  } = _ref;
  // Default colors are primary
  var backgroundColor = theme.COLORS.primary;
  var textColor = theme.COLORS.white;

  if (status === 'primary' && isLowContrast) {
    backgroundColor = theme.COLORS.defaultLight;
    textColor = theme.COLORS.primary;
  }

  if (status === 'error') {
    backgroundColor = theme.COLORS.error;
    textColor = theme.COLORS.white;

    if (isLowContrast) {
      backgroundColor = theme.COLORS.errorLight;
      textColor = theme.COLORS.error;
    }
  }

  if (status === 'success') {
    backgroundColor = theme.COLORS.success;
    textColor = theme.COLORS.white;

    if (isLowContrast) {
      backgroundColor = theme.COLORS.successBorder;
      textColor = theme.COLORS.success;
    }
  }

  if (status === 'white') {
    /**
     * No low-contrast version of white variation
     */
    backgroundColor = theme.COLORS.white;
    textColor = theme.COLORS.primary;
  }

  return {
    backgroundColor,
    textColor
  };
};
/**
 * Chips should be used in small spaces to add value to the elements they're nested in. (i.e. "Recommended" on product cards or showing an error on an element in a list.)
 *
 * These chips can have a status value of Error, Primary, Success, or White. "White" does not have a low contrast version, and can be used on top of photos or illustrations.
 */


var Chip = _ref2 => {
  var {
    isLowContrast = false,
    status = 'primary',
    text
  } = _ref2;
  var theme = react.useTheme();
  var {
    backgroundColor,
    textColor
  } = getStyles({
    isLowContrast,
    status,
    theme
  });
  return react.jsx(style["default"].ChipStyles, {
    backgroundColor: backgroundColor,
    textColor: textColor
  }, react.jsx(style["default"].ChipText, null, text));
};
Chip.propTypes = {
  isLowContrast: PropTypes__default["default"].bool,
  status: PropTypes__default["default"].oneOf(['primary', 'success', 'error', 'white']),
  text: PropTypes__default["default"].string.isRequired
};

exports.Chip = Chip;
