'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('@babel/runtime/helpers/extends');
var _objectWithoutProperties = require('@babel/runtime/helpers/objectWithoutProperties');
var PropTypes = require('prop-types');
var React = require('react');
var ReactDOM = require('react-dom');
var reactTransitionGroup = require('react-transition-group');
var focus = require('@react-aria/focus');
var react = require('@emotion/react');
var index = require('../../constants/portals/index.cjs');
require('../icon/index.cjs');
var crossIcon = require('../../icons/icons/crossIcon.cjs');
var style = require('./style.cjs');
require('../../constants/breakpoints/index.cjs');
require('../../constants/grid/index.cjs');
require('../../constants/mediaQueries/index.cjs');
var primaryTheme = require('../../constants/themes/primaryTheme.cjs');
var secondaryTheme = require('../../constants/themes/secondaryTheme.cjs');
require('../../constants/themes/types.cjs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _extends__default = /*#__PURE__*/_interopDefaultLegacy(_extends);
var _objectWithoutProperties__default = /*#__PURE__*/_interopDefaultLegacy(_objectWithoutProperties);
var PropTypes__default = /*#__PURE__*/_interopDefaultLegacy(PropTypes);
var ReactDOM__default = /*#__PURE__*/_interopDefaultLegacy(ReactDOM);

var _excluded = ["backgroundColor", "children", "onCloseIconClick", "title"];

var getHtmlNode = () => {
  var _document$querySelect;

  return (_document$querySelect = document.querySelector('html')) !== null && _document$querySelect !== void 0 ? _document$querySelect : document.body;
};

var getDomNode = () => {
  var _document$getElementB;

  return (_document$getElementB = document.getElementById(index.REACT_PORTAL_SECTION_ID)) !== null && _document$getElementB !== void 0 ? _document$getElementB : document.body;
};
/**
 * Dialog modals shouldn't contain large content and should not scroll unless screen size dictates it. To display large amounts of content, use `Immersive modal` instead.
 *
 * Dialog modals require a user to make a choice between options and are not closable on click/tap outside. They may contain a close button if a close function is provided.
 *
 * Dialog Modals should always contain at least 1 button and the logic should close the modal at some point.
 *
 * `DialogModal.Paragraph` subcomponent may be used to add some margin to the paragraphs inside the modal body.
 */


var DialogModal = _ref => {
  var {
    backgroundColor,
    children,
    onCloseIconClick,
    title = ''
  } = _ref,
      rest = _objectWithoutProperties__default["default"](_ref, _excluded);

  var theme = react.useTheme();
  var backgroundColorWithTheme = backgroundColor !== null && backgroundColor !== void 0 ? backgroundColor : theme.COLORS.white;
  var [isClosing, setIsClosing] = React.useState(false);
  var domNode = React.useRef(getDomNode());
  var htmlNode = React.useRef(getHtmlNode());
  React.useEffect(() => {
    domNode.current = getDomNode();
    htmlNode.current = getHtmlNode();
    var htmlNodeInstance = htmlNode.current;
    htmlNodeInstance.classList.add('no-scroll');
    return () => {
      htmlNodeInstance.classList.remove('no-scroll');
    };
  }, []);

  var handleCloseIntent = () => {
    if (onCloseIconClick) {
      setIsClosing(true);
      setTimeout(onCloseIconClick, 350);
    }
  };

  var handleKeyDown = event => {
    if (event.key === 'Escape') {
      handleCloseIntent();
    }
  };

  return /*#__PURE__*/ReactDOM__default["default"].createPortal(react.jsx(reactTransitionGroup.Transition, {
    appear: true,
    in: !isClosing,
    timeout: {
      appear: 0,
      enter: 0,
      exit: 250
    },
    unmountOnExit: true
  }, transitionState => // eslint-disable-next-line react/jsx-props-no-spreading
  react.jsx(style["default"].Overlay, _extends__default["default"]({
    className: transitionState
  }, rest), react.jsx(focus.FocusScope, {
    contain: true,
    restoreFocus: true,
    autoFocus: true
  }, react.jsx(style["default"].ModalContainer, {
    backgroundColor: backgroundColorWithTheme,
    className: transitionState,
    onKeyDown: handleKeyDown
  }, onCloseIconClick && react.jsx(style["default"].CrossIconContainer, {
    backgroundColor: backgroundColorWithTheme,
    onClick: handleCloseIntent,
    role: "button",
    tabIndex: 0,
    "aria-label": "Close modal"
  }, react.jsx(crossIcon["default"], null)), !!title && react.jsx(style["default"].ModalTitle, null, title), children)))), domNode.current);
};
DialogModal.Paragraph = style["default"].Paragraph;
DialogModal.propTypes = {
  backgroundColor: PropTypes__default["default"].oneOf([primaryTheme.primaryTheme.COLORS.background, secondaryTheme.secondaryTheme.COLORS.background]),
  children: PropTypes__default["default"].node.isRequired,
  onCloseIconClick: PropTypes__default["default"].func,
  title: PropTypes__default["default"].string
};

exports.DialogModal = DialogModal;
