import React from 'react';
import Style from './style';
import { Colors } from '../../constants';
export interface DialogModalProps {
    /**
     * DialogModal background color. Defaults to the current theme's `white` if not specified.
     */
    backgroundColor?: Colors['background'];
    /**
     * Dialog Modal content.
     * Must contain at least 1 button and is responsible for closing the modal.
     */
    children: React.ReactNode;
    /**
     * If provided, DialogModal displays a Close Icon positioned top-right.
     * This function must contain the logic for closing the modal.
     */
    onCloseIconClick?: (() => void) | null;
    title?: string;
    [key: string]: unknown;
}
interface DialogModal extends React.FC<DialogModalProps> {
    Paragraph: typeof Style.Paragraph;
}
/**
 * Dialog modals shouldn't contain large content and should not scroll unless screen size dictates it. To display large amounts of content, use `Immersive modal` instead.
 *
 * Dialog modals require a user to make a choice between options and are not closable on click/tap outside. They may contain a close button if a close function is provided.
 *
 * Dialog Modals should always contain at least 1 button and the logic should close the modal at some point.
 *
 * `DialogModal.Paragraph` subcomponent may be used to add some margin to the paragraphs inside the modal body.
 */
export declare const DialogModal: DialogModal;
export {};
//# sourceMappingURL=index.d.ts.map