import { useState } from 'react';
import PropTypes from 'prop-types';
import { useTheme, jsx } from '@emotion/react';
import { MobileDropdown } from './mobileDropdown.js';
import { DesktopDropdown } from './desktopDropdown.js';
import { isDefined } from '../../utils/isDefined/index.js';

var Dropdown = _ref => {
  var {
    borderRadius,
    id,
    onChange,
    onDropdownContainerFocus,
    options,
    optionsContainerMaxHeight = '250px',
    textAlign = 'left',
    value
  } = _ref;
  var theme = useTheme();
  var [isOpen, setIsOpen] = useState(false);
  var touchSupported = ('ontouchstart' in document.documentElement);
  var borderRadiusValue = borderRadius !== null && borderRadius !== void 0 ? borderRadius : theme.BORDER_RADIUS.small;

  var toggleDropdown = () => {
    setIsOpen(prevIsOpen => !prevIsOpen);
  };

  var closeDropdown = () => {
    setIsOpen(false);
  };

  var onMobileSelectChange = event => {
    var {
      target
    } = event;
    var {
      selectedIndex,
      selectedOptions
    } = target;
    var selectedOption = options[selectedIndex];

    if (selectedOptions.length) {
      onChange(selectedOption);
    }

    closeDropdown();
  };

  var onDesktopSelectChange = event => {
    var _currentTarget$getAtt;

    var {
      currentTarget
    } = event;

    if (currentTarget.hasAttribute('disabled')) {
      return;
    } // Next Value may be returned as null if the value of <li> is undefined. We want to cast to the real value of undefined


    var nextValue = (_currentTarget$getAtt = currentTarget.getAttribute('value')) !== null && _currentTarget$getAtt !== void 0 ? _currentTarget$getAtt : undefined;
    var selectedOption = options.find(option => {
      var {
        value: optionValue
      } = option; // This covers numbers and strings. <li> value is always returned as string. Falsy case covers undefined.

      return isDefined(optionValue) ? "".concat(optionValue) === nextValue : optionValue === nextValue;
    });

    if (selectedOption) {
      onChange(selectedOption);
    }

    closeDropdown();
  };

  var handleOnDropdownContainerFocus = event => {
    if (onDropdownContainerFocus) {
      onDropdownContainerFocus(event);
    }
  };

  if (touchSupported) {
    return jsx(MobileDropdown, {
      borderRadius: borderRadiusValue,
      id: id,
      onMobileSelectChange: onMobileSelectChange,
      onDropdownContainerFocus: handleOnDropdownContainerFocus,
      options: options,
      textAlign: textAlign,
      value: value
    });
  }

  var currentOption = options.find(option => option.value === value);
  return jsx(DesktopDropdown, {
    borderRadius: borderRadiusValue,
    closeDropdown: closeDropdown,
    currentOption: currentOption,
    id: id,
    isOpen: isOpen,
    onDesktopSelectChange: onDesktopSelectChange,
    onDropdownContainerFocus: handleOnDropdownContainerFocus,
    options: options,
    optionsContainerMaxHeight: optionsContainerMaxHeight,
    textAlign: textAlign,
    toggleDropdown: toggleDropdown,
    value: value
  });
};
Dropdown.propTypes = {
  borderRadius: PropTypes.string,
  id: PropTypes.string,
  onChange: PropTypes.func.isRequired,
  options: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    label: PropTypes.string.isRequired,
    disabled: PropTypes.bool
  }).isRequired).isRequired,
  optionsContainerMaxHeight: PropTypes.string,
  textAlign: PropTypes.oneOf(['left', 'center']),
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
};

export { Dropdown };
