import 'focus-visible';
import { baseBodyStyles } from '../typography/index.js';

/**
 * Enables use of the .focus-visible polyfill.
 *
 * This will allow us to differentiate focus styling between mouse focus and keyboard focus.
 *
 * This *does not* apply to input tags. For more details, see {@link https://github.com/WICG/focus-visible/blob/fda80f8401807c1cbb702fb1a15b9635828bfc6d/README.md#how-it-works "How It Works" section}
 *
 * {@link https://github.com/WICG/focus-visible Github README}
 *
 * {@link https://wicg.github.io/focus-visible/demo/ W3C Playground}
 */

var focusStyles = "\n.js-focus-visible :focus:not(.focus-visible) {\n  outline: 0;\n  box-shadow: none;\n}";
var resetStyles = "\n  html {\n    box-sizing: border-box;\n    -ms-overflow-style: scrollbar;\n    -webkit-tap-highlight-color: transparent;\n  }\n\n  *,\n  *::before,\n  *::after {\n    box-sizing: inherit;\n  }\n\n  [tabindex=\"-1\"]:focus {\n    outline: none !important;\n  }\n\n  h1, h2, h3, h4, h5, h6 {\n    margin: 0;\n  }\n\n  p {\n    margin: 0;\n  }\n\n  abbr[title],\n  abbr[data-original-title] {\n    cursor: help;\n  }\n\n  address {\n    margin-bottom: 1rem;\n    font-style: normal;\n    line-height: inherit;\n  }\n\n  ol,\n  ul,\n  dl {\n    margin-top: 0;\n    margin-bottom: 1rem;\n  }\n\n  ol ol,\n  ul ul,\n  ol ul,\n  ul ol {\n    margin-bottom: 0;\n  }\n\n  dd {\n    margin-bottom: .5rem;\n    margin-left: 0; // Undo browser default\n  }\n\n  blockquote {\n    margin: 0 0 1rem;\n  }\n\n  a:not([href]):not([tabindex]) {\n    text-decoration: none;\n\n    &:hover,\n    &:focus {\n      color: inherit;\n      text-decoration: none;\n    }\n\n    &:focus {\n      outline: 0;\n    }\n  }\n\n  pre {\n    margin-top: 0;\n    margin-bottom: 1rem;\n    overflow: auto;\n  }\n\n  figure {\n    margin: 0 0 1rem;\n  }\n\n  img {\n    display: block;\n    max-width: 100%;\n    vertical-align: middle;\n  }\n\n  [role=\"button\"] {\n    cursor: pointer;\n  }\n\n  a,\n  area,\n  button,\n  [role=\"button\"],\n  input,\n  label,\n  select,\n  summary,\n  textarea {\n    touch-action: manipulation;\n  }\n\n  table {\n    border-collapse: collapse;\n  }\n\n  caption {\n    text-align: left;\n    caption-side: bottom;\n  }\n\n  th {\n    text-align: left;\n  }\n\n  label {\n    display: inline-block;\n    margin-bottom: 0rem;\n  }\n\n  button:focus {\n    outline: 1px dotted;\n    outline: 5px auto -webkit-focus-ring-color;\n  }\n\n  input,\n  button,\n  select,\n  textarea {\n    line-height: inherit;\n    font-family: inherit;\n    font-size: inherit;\n  }\n\n  input[type=\"radio\"],\n  input[type=\"checkbox\"] {\n    &:disabled {\n      cursor: not-allowed;\n    }\n  }\n\n\n  input[type=\"date\"],\n  input[type=\"time\"],\n  input[type=\"datetime-local\"],\n  input[type=\"month\"] {\n    -webkit-appearance: listbox;\n  }\n\n  textarea {\n    resize: vertical;\n  }\n\n  fieldset {\n    min-width: 0;\n    padding: 0;\n    margin: 0;\n    border: 0;\n  }\n\n  legend {\n    display: block;\n    width: 100%;\n    padding: 0;\n    margin-bottom: .5rem;\n    font-size: 1.5rem;\n    line-height: inherit;\n  }\n\n  input {\n    border-radius: 0;\n    -webkit-appearance: none;\n  }\n\n  [hidden] {\n    display: none !important;\n  }\n\n  ".concat(focusStyles, "\n");
var brandStyles = theme => "\n  html {\n    overflow-x: hidden;\n    font-size: 16px;\n  }\n\n  body {\n    -moz-osx-font-smoothing: grayscale;\n    -webkit-font-smoothing: antialiased;\n    ".concat(baseBodyStyles(theme), "\n    background-color: ").concat(theme.COLORS.white, ";\n    font-family: ").concat(theme.FONTS.baseFont, ";\n    font-weight: ").concat(theme.TYPOGRAPHY.fontWeight.normal, ";\n    margin: 0;\n    transition-timing-function: ease-in-out;\n  }\n\n  input:is([type=\"button\"], [type=\"submit\"], [type=\"reset\"]), input[type=\"file\"]::file-selector-button, button {\n    color: ").concat(theme.COLORS.primary, ";\n  }\n\n  img {\n    max-width: 100%;\n  }\n\n  ul {\n    list-style: none;\n    padding: 0;\n  }\n\n  a {\n    color: inherit;\n  }\n\n  p a {\n    color: inherit;\n    border-bottom: 1px solid;\n    text-decoration: none;\n    transition: 350ms;\n\n    &:hover,\n    &:focus,\n    &:visited {\n      opacity: .6;\n      transition: 350ms;\n    }\n  }\n\n  iframe[name='google_conversion_frame'] {\n    float: left;\n    font-size: 0 !important;\n    height: 0 !important;\n    line-height: 0 !important;\n    margin-top: -13px;\n    width: 0 !important;\n  }\n\n  [data-name='mojs-shape'] {\n    pointer-events: none;\n    z-index: 1;\n  }\n\n  .no-scroll {\n    overflow: hidden;\n  }\n");

export { brandStyles, resetStyles };
