'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('@babel/runtime/helpers/extends');
var _objectWithoutProperties = require('@babel/runtime/helpers/objectWithoutProperties');
require('react');
var PropTypes = require('prop-types');
var style = require('./style.cjs');
var react = require('@emotion/react');
require('../icon/index.cjs');
var checkmarkIcon = require('../../icons/icons/checkmarkIcon.cjs');
var index = require('../../utils/isDefined/index.cjs');
require('../../constants/breakpoints/index.cjs');
require('../../constants/grid/index.cjs');
require('../../constants/mediaQueries/index.cjs');
require('../../constants/colors/primary.cjs');
require('../../constants/boxShadows/primary.cjs');
require('../../constants/colors/secondary.cjs');
require('../../constants/boxShadows/secondary.cjs');
var types = require('../../constants/themes/types.cjs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _extends__default = /*#__PURE__*/_interopDefaultLegacy(_extends);
var _objectWithoutProperties__default = /*#__PURE__*/_interopDefaultLegacy(_objectWithoutProperties);
var PropTypes__default = /*#__PURE__*/_interopDefaultLegacy(PropTypes);

var _excluded = ["borderRadius", "buttonType", "icon", "onClick", "optionType", "selected", "subtext", "text"],
    _excluded2 = ["borderRadius", "icon", "optionType", "subtext", "text"];
var DEFAULT_BORDER_RADIUS = 'small';

var OptionButtonContent = _ref => {
  var {
    buttonType = 'primary',
    icon,
    optionType,
    selected = false,
    subtext,
    text
  } = _ref;
  return react.jsx(style["default"].FlexContainer, null, index.isDefined(icon) && icon !== false ? react.jsx(style["default"].IconWrapper, {
    selected: selected,
    optionType: optionType,
    buttonType: buttonType
  }, selected ? react.jsx(checkmarkIcon["default"], null) : icon) : react.jsx(style["default"].CheckmarkWrapper, {
    selected: selected,
    optionType: optionType,
    buttonType: buttonType
  }, react.jsx(checkmarkIcon["default"], null)), react.jsx(style["default"].TextContainer, null, react.jsx(style["default"].Text, null, text), index.isDefined(subtext) && react.jsx(style["default"].SubText, null, subtext)));
};
/**
 * The `OptionButton` is used within a focused flow (such as the signup page)
 * to provide more context and attention to each selection option.
 *
 * There is also an OptionButton.Container sub-component to be used when we
 * want to use the OptionButton as a purely presentational component rather
 * than a functional button associated with form inputs
 */


var OptionButton = _ref2 => {
  var {
    borderRadius = DEFAULT_BORDER_RADIUS,
    buttonType,
    icon,
    onClick,
    optionType,
    selected,
    subtext,
    text
  } = _ref2,
      rest = _objectWithoutProperties__default["default"](_ref2, _excluded);

  return react.jsx(style["default"].ClickableContainer, _extends__default["default"]({
    borderRadius: borderRadius,
    onClick: onClick,
    type: "button",
    role: optionType,
    containerType: "clickable" // eslint-disable-next-line react/jsx-props-no-spreading

  }, rest), react.jsx(OptionButtonContent, {
    buttonType: buttonType,
    icon: icon,
    optionType: optionType,
    selected: selected,
    subtext: subtext,
    text: text
  }));
};
/**
 * A presentational component to match the display of an OptionButton with an icon
 */

var OptionButtonNotClickable = _ref3 => {
  var {
    borderRadius = DEFAULT_BORDER_RADIUS,
    icon,
    optionType,
    subtext,
    text
  } = _ref3,
      rest = _objectWithoutProperties__default["default"](_ref3, _excluded2);

  return react.jsx(style["default"].DisplayContainer, _extends__default["default"]({
    borderRadius: borderRadius,
    containerType: "none" // eslint-disable-next-line react/jsx-props-no-spreading

  }, rest), react.jsx(OptionButtonContent // The buttonType does not matter for this component
  , {
    buttonType: "primary",
    icon: icon,
    optionType: optionType,
    selected: false,
    subtext: subtext,
    text: text
  }));
};
/**
 * Similar OptionButton styling without click elements
 */

OptionButton.NotClickable = OptionButtonNotClickable;
OptionButton.propTypes = {
  borderRadius: types.BORDER_RADIUS_PROP_TYPES,
  buttonType: PropTypes__default["default"].oneOf(['primary', 'secondary']),
  icon: PropTypes__default["default"].node,
  onClick: PropTypes__default["default"].func.isRequired,
  optionType: PropTypes__default["default"].oneOf(['radio', 'checkbox']).isRequired,
  selected: PropTypes__default["default"].bool,
  subtext: PropTypes__default["default"].node,
  text: PropTypes__default["default"].string.isRequired
};

exports.OptionButton = OptionButton;
exports.OptionButtonNotClickable = OptionButtonNotClickable;
