import _extends from '@babel/runtime/helpers/extends';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import 'react';
import PropTypes from 'prop-types';
import Style from './style.js';
import { jsx } from '@emotion/react';
import '../icon/index.js';
import CheckmarkIcon from '../../icons/icons/checkmarkIcon.js';
import { isDefined } from '../../utils/isDefined/index.js';
import '../../constants/breakpoints/index.js';
import '../../constants/grid/index.js';
import '../../constants/mediaQueries/index.js';
import '../../constants/colors/primary.js';
import '../../constants/boxShadows/primary.js';
import '../../constants/colors/secondary.js';
import '../../constants/boxShadows/secondary.js';
import { BORDER_RADIUS_PROP_TYPES } from '../../constants/themes/types.js';

var _excluded = ["borderRadius", "buttonType", "icon", "onClick", "optionType", "selected", "subtext", "text"],
    _excluded2 = ["borderRadius", "icon", "optionType", "subtext", "text"];
var DEFAULT_BORDER_RADIUS = 'small';

var OptionButtonContent = _ref => {
  var {
    buttonType = 'primary',
    icon,
    optionType,
    selected = false,
    subtext,
    text
  } = _ref;
  return jsx(Style.FlexContainer, null, isDefined(icon) && icon !== false ? jsx(Style.IconWrapper, {
    selected: selected,
    optionType: optionType,
    buttonType: buttonType
  }, selected ? jsx(CheckmarkIcon, null) : icon) : jsx(Style.CheckmarkWrapper, {
    selected: selected,
    optionType: optionType,
    buttonType: buttonType
  }, jsx(CheckmarkIcon, null)), jsx(Style.TextContainer, null, jsx(Style.Text, null, text), isDefined(subtext) && jsx(Style.SubText, null, subtext)));
};
/**
 * The `OptionButton` is used within a focused flow (such as the signup page)
 * to provide more context and attention to each selection option.
 *
 * There is also an OptionButton.Container sub-component to be used when we
 * want to use the OptionButton as a purely presentational component rather
 * than a functional button associated with form inputs
 */


var OptionButton = _ref2 => {
  var {
    borderRadius = DEFAULT_BORDER_RADIUS,
    buttonType,
    icon,
    onClick,
    optionType,
    selected,
    subtext,
    text
  } = _ref2,
      rest = _objectWithoutProperties(_ref2, _excluded);

  return jsx(Style.ClickableContainer, _extends({
    borderRadius: borderRadius,
    onClick: onClick,
    type: "button",
    role: optionType,
    containerType: "clickable" // eslint-disable-next-line react/jsx-props-no-spreading

  }, rest), jsx(OptionButtonContent, {
    buttonType: buttonType,
    icon: icon,
    optionType: optionType,
    selected: selected,
    subtext: subtext,
    text: text
  }));
};
/**
 * A presentational component to match the display of an OptionButton with an icon
 */

var OptionButtonNotClickable = _ref3 => {
  var {
    borderRadius = DEFAULT_BORDER_RADIUS,
    icon,
    optionType,
    subtext,
    text
  } = _ref3,
      rest = _objectWithoutProperties(_ref3, _excluded2);

  return jsx(Style.DisplayContainer, _extends({
    borderRadius: borderRadius,
    containerType: "none" // eslint-disable-next-line react/jsx-props-no-spreading

  }, rest), jsx(OptionButtonContent // The buttonType does not matter for this component
  , {
    buttonType: "primary",
    icon: icon,
    optionType: optionType,
    selected: false,
    subtext: subtext,
    text: text
  }));
};
/**
 * Similar OptionButton styling without click elements
 */

OptionButton.NotClickable = OptionButtonNotClickable;
OptionButton.propTypes = {
  borderRadius: BORDER_RADIUS_PROP_TYPES,
  buttonType: PropTypes.oneOf(['primary', 'secondary']),
  icon: PropTypes.node,
  onClick: PropTypes.func.isRequired,
  optionType: PropTypes.oneOf(['radio', 'checkbox']).isRequired,
  selected: PropTypes.bool,
  subtext: PropTypes.node,
  text: PropTypes.string.isRequired
};

export { OptionButton, OptionButtonNotClickable };
