import _extends from '@babel/runtime/helpers/extends';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import 'react';
import PropTypes from 'prop-types';
import { useTheme, jsx } from '@emotion/react';
import '../../constants/breakpoints/index.js';
import '../../constants/grid/index.js';
import '../../constants/mediaQueries/index.js';
import PROGRESS_BAR_STATUS from '../../constants/progressBarStatus/index.js';
import '../../constants/colors/primary.js';
import '../../constants/boxShadows/primary.js';
import '../../constants/colors/secondary.js';
import '../../constants/boxShadows/secondary.js';
import { COLORS_PROP_TYPES } from '../../constants/themes/types.js';
import Style from './style.js';

var _excluded = ["backgroundColor", "barColor", "height", "loadingTime", "status"];
var ProgressBar = _ref => {
  var {
    backgroundColor,
    barColor,
    height = 4,
    loadingTime = '20s',
    status
  } = _ref,
      rest = _objectWithoutProperties(_ref, _excluded);

  var theme = useTheme();
  var backgroundColorWithTheme = backgroundColor !== null && backgroundColor !== void 0 ? backgroundColor : theme.COLORS.background;
  var barColorWithTheme = barColor !== null && barColor !== void 0 ? barColor : theme.COLORS.primary;
  return jsx(Style.OuterContainer, _extends({
    status: status,
    barHeight: height,
    backgroundColor: backgroundColorWithTheme // eslint-disable-next-line react/jsx-props-no-spreading

  }, rest), jsx(Style.InnerBar, {
    status: status,
    barHeight: height,
    barColor: barColorWithTheme,
    loadingTime: loadingTime
  }));
};
ProgressBar.propTypes = {
  backgroundColor: COLORS_PROP_TYPES,
  barColor: COLORS_PROP_TYPES,
  height: PropTypes.number,
  loadingTime: PropTypes.string,
  status: PropTypes.oneOf([PROGRESS_BAR_STATUS.loading, PROGRESS_BAR_STATUS.success, PROGRESS_BAR_STATUS.error]).isRequired
};

export { ProgressBar };
