'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var style = require('./style.cjs');
var react = require('@emotion/react');

var SegmentedControl = _ref => {
  var {
    segmentItems,
    initialActiveId = 1,
    onClick
  } = _ref;
  var itemsCount = segmentItems.length;

  if (itemsCount === 0) {
    return null;
  }

  var initialActiveItem = segmentItems.find(item => item.id === initialActiveId);
  var initialActiveIndex = initialActiveItem ? segmentItems.indexOf(initialActiveItem) : 0;
  var [activeSegmentText, setActiveSegmentText] = React.useState(() => initialActiveItem ? initialActiveItem.text : segmentItems[0].text);
  var [activeSegmentIndex, setActiveSegmentIndex] = React.useState(initialActiveIndex);
  var targetRef = React.useRef(null);
  var [transform, setTransform] = React.useState('');
  var [targetWidth, setTargetWidth] = React.useState(0);
  var segmentWidth = 100 / itemsCount;
  React.useEffect(() => {
    if (targetRef.current) {
      setTargetWidth(targetRef.current.offsetWidth);
      setTransform("translate3d(".concat(targetRef.current.offsetWidth * activeSegmentIndex, "px, 0, 0)"));
    }
  }, [targetRef]);

  var onSegmentClick = (segment, index) => {
    setActiveSegmentText(segment.text);
    setActiveSegmentIndex(index);
    setTransform("translate3d(".concat(targetWidth * index, "px, 0, 0)"));

    if (onClick) {
      onClick(segment);
    }
  };

  return react.jsx(style.SegmentsContainer, null, react.jsx(style.Indicator, {
    segmentWidth: segmentWidth,
    transform: transform,
    ref: targetRef
  }, activeSegmentText), segmentItems.map((segment, index) => react.jsx(style.SegmentItem, {
    segmentWidth: segmentWidth,
    active: index === activeSegmentIndex,
    key: segment.id,
    onClick: () => {
      onSegmentClick(segment, index);
    },
    disabled: index === activeSegmentIndex
  }, segment.text)));
};

exports.SegmentedControl = SegmentedControl;
