'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');

/**
 * Returns a ref and a function for sending focus to the ref's DOM element.
 * Useful for moving keyboard focus after an event.
 * @example
 * const { initialFocus, resetFocus } = useResetFocus();
 * return (
 *  <React.Fragment>
 *    <button ref={initialFocus}>First Button</button>
 *    <button onClick={() => resetFocus() }>Click Here to send focus to the First Button!</button>
 *  </React.Fragment>
 * );
 *
 */

var useResetFocus = () => {
  var ref = React.useRef(null);

  var resetFocus = () => {
    if (ref.current) {
      ref.current.focus();
    }
  };

  return {
    initialFocus: ref,
    resetFocus
  };
};

exports["default"] = useResetFocus;
